"""Package metadata. """

__doc__ = "This package is design to scrape Bible data on JW.org for NLP/IAgen task."
__name__ = "jwsoup"
__author__ = "Salif SAWADOGO"
__email__ = "salif.sawadogo.pro@gmail.com"
__version__ = "0.0.5"
__url__ = "https://github.com/sawadogosalif/jwsoup.git"
